summaryrefslogtreecommitdiffstats
path: root/pyload/plugin/hook
diff options
context:
space:
mode:
Diffstat (limited to 'pyload/plugin/hook')
-rw-r--r--pyload/plugin/hook/AlldebridCom.py14
-rw-r--r--pyload/plugin/hook/BypassCaptcha.py22
-rw-r--r--pyload/plugin/hook/Captcha9kw.py14
-rw-r--r--pyload/plugin/hook/CaptchaBrotherhood.py18
-rw-r--r--pyload/plugin/hook/DeathByCaptcha.py18
-rw-r--r--pyload/plugin/hook/DebridItaliaCom.py14
-rw-r--r--pyload/plugin/hook/EasybytezCom.py16
-rw-r--r--pyload/plugin/hook/ExpertDecoders.py14
-rw-r--r--pyload/plugin/hook/FastixRu.py14
-rw-r--r--pyload/plugin/hook/FreeWayMe.py14
-rw-r--r--pyload/plugin/hook/ImageTyperz.py20
-rw-r--r--pyload/plugin/hook/LinkdecrypterCom.py14
-rw-r--r--pyload/plugin/hook/LinksnappyCom.py14
-rw-r--r--pyload/plugin/hook/MegaDebridEu.py14
-rw-r--r--pyload/plugin/hook/MultishareCz.py14
-rw-r--r--pyload/plugin/hook/MyfastfileCom.py14
-rw-r--r--pyload/plugin/hook/OverLoadMe.py14
-rw-r--r--pyload/plugin/hook/PremiumTo.py14
-rw-r--r--pyload/plugin/hook/PremiumizeMe.py14
-rw-r--r--pyload/plugin/hook/RPNetBiz.py14
-rw-r--r--pyload/plugin/hook/RealdebridCom.py14
-rw-r--r--pyload/plugin/hook/RehostTo.py14
-rw-r--r--pyload/plugin/hook/SimplyPremiumCom.py14
-rw-r--r--pyload/plugin/hook/SimplydebridCom.py14
-rw-r--r--pyload/plugin/hook/UnrestrictLi.py14
-rw-r--r--pyload/plugin/hook/XFileSharingPro.py16
-rw-r--r--pyload/plugin/hook/ZeveraCom.py14
27 files changed, 202 insertions, 202 deletions
diff --git a/pyload/plugin/hook/AlldebridCom.py b/pyload/plugin/hook/AlldebridCom.py
index 3297c12e3..5d4a2f4f4 100644
--- a/pyload/plugin/hook/AlldebridCom.py
+++ b/pyload/plugin/hook/AlldebridCom.py
@@ -5,19 +5,19 @@ from pyload.plugin.internal.MultiHoster import MultiHoster
class AlldebridCom(MultiHoster):
- __name = "AlldebridCom"
- __type = "hook"
- __version = "0.13"
+ __name__ = "AlldebridCom"
+ __type__ = "hook"
+ __version__ = "0.13"
- __config = [("https", "bool", "Enable HTTPS", False),
+ __config__ = [("https", "bool", "Enable HTTPS", False),
("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported)", "all"),
("hosterList", "str", "Hoster list (comma separated)", ""),
("unloadFailing", "bool", "Revert to stanard download if download fails", False),
("interval", "int", "Reload interval in hours (0 to disable)", 24)]
- __description = """Alldebrid.com hook plugin"""
- __license = "GPLv3"
- __authors = [("Andy Voigt", "spamsales@online.de")]
+ __description__ = """Alldebrid.com hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("Andy Voigt", "spamsales@online.de")]
def getHoster(self):
diff --git a/pyload/plugin/hook/BypassCaptcha.py b/pyload/plugin/hook/BypassCaptcha.py
index 20a1582cc..038d7db79 100644
--- a/pyload/plugin/hook/BypassCaptcha.py
+++ b/pyload/plugin/hook/BypassCaptcha.py
@@ -26,16 +26,16 @@ class BypassCaptchaException(Exception):
class BypassCaptcha(Addon):
- __name = "BypassCaptcha"
- __type = "hook"
- __version = "0.05"
+ __name__ = "BypassCaptcha"
+ __type__ = "hook"
+ __version__ = "0.05"
- __config = [("force", "bool", "Force BC even if client is connected", False),
+ __config__ = [("force", "bool", "Force BC even if client is connected", False),
("passkey", "password", "Passkey", "")]
- __description = """Send captchas to BypassCaptcha.com"""
- __license = "GPLv3"
- __authors = [("RaNaN", "RaNaN@pyload.org"),
+ __description__ = """Send captchas to BypassCaptcha.com"""
+ __license__ = "GPLv3"
+ __authors__ = [("RaNaN", "RaNaN@pyload.org"),
("Godofdream", "soilfcition@gmail.com"),
("zoidberg", "zoidberg@mujmail.cz")]
@@ -104,20 +104,20 @@ class BypassCaptcha(Addon):
if self.getCredits() > 0:
task.handler.append(self)
- task.data['service'] = self.__name
+ task.data['service'] = self.__name__
task.setWaiting(100)
self.processCaptcha(task)
else:
- self.logInfo(_("Your %s account has not enough credits") % self.__name)
+ self.logInfo(_("Your %s account has not enough credits") % self.__name__)
def captchaCorrect(self, task):
- if task.data['service'] == self.__name and "ticket" in task.data:
+ if task.data['service'] == self.__name__ and "ticket" in task.data:
self.respond(task.data['ticket'], True)
def captchaInvalid(self, task):
- if task.data['service'] == self.__name and "ticket" in task.data:
+ if task.data['service'] == self.__name__ and "ticket" in task.data:
self.respond(task.data['ticket'], False)
diff --git a/pyload/plugin/hook/Captcha9kw.py b/pyload/plugin/hook/Captcha9kw.py
index dafbf72b3..a74983d9b 100644
--- a/pyload/plugin/hook/Captcha9kw.py
+++ b/pyload/plugin/hook/Captcha9kw.py
@@ -14,11 +14,11 @@ from pyload.plugin.Addon import Addon
class Captcha9kw(Addon):
- __name = "Captcha9kw"
- __type = "hook"
- __version = "0.26"
+ __name__ = "Captcha9kw"
+ __type__ = "hook"
+ __version__ = "0.26"
- __config = [("ssl" , "bool" , "Use HTTPS" , True ),
+ __config__ = [("ssl" , "bool" , "Use HTTPS" , True ),
("force" , "bool" , "Force captcha resolving even if client is connected" , True ),
("confirm" , "bool" , "Confirm Captcha (cost +6 credits)" , False ),
("captchaperhour", "int" , "Captcha per hour" , "9999" ),
@@ -30,9 +30,9 @@ class Captcha9kw(Addon):
("passkey" , "password", "API key" , "" ),
("timeout" , "int" , "Timeout in seconds (min 60, max 3999)" , "900" )]
- __description = """Send captchas to 9kw.eu"""
- __license = "GPLv3"
- __authors = [("RaNaN", "RaNaN@pyload.org"),
+ __description__ = """Send captchas to 9kw.eu"""
+ __license__ = "GPLv3"
+ __authors__ = [("RaNaN", "RaNaN@pyload.org"),
("Walter Purcaro", "vuolter@gmail.com")]
diff --git a/pyload/plugin/hook/CaptchaBrotherhood.py b/pyload/plugin/hook/CaptchaBrotherhood.py
index d01d262f2..7bbd85659 100644
--- a/pyload/plugin/hook/CaptchaBrotherhood.py
+++ b/pyload/plugin/hook/CaptchaBrotherhood.py
@@ -36,17 +36,17 @@ class CaptchaBrotherhoodException(Exception):
class CaptchaBrotherhood(Addon):
- __name = "CaptchaBrotherhood"
- __type = "hook"
- __version = "0.06"
+ __name__ = "CaptchaBrotherhood"
+ __type__ = "hook"
+ __version__ = "0.06"
- __config = [("username", "str", "Username", ""),
+ __config__ = [("username", "str", "Username", ""),
("force", "bool", "Force CT even if client is connected", False),
("passkey", "password", "Password", "")]
- __description = """Send captchas to CaptchaBrotherhood.com"""
- __license = "GPLv3"
- __authors = [("RaNaN", "RaNaN@pyload.org"),
+ __description__ = """Send captchas to CaptchaBrotherhood.com"""
+ __license__ = "GPLv3"
+ __authors__ = [("RaNaN", "RaNaN@pyload.org"),
("zoidberg", "zoidberg@mujmail.cz")]
@@ -142,7 +142,7 @@ class CaptchaBrotherhood(Addon):
if self.getCredits() > 10:
task.handler.append(self)
- task.data['service'] = self.__name
+ task.data['service'] = self.__name__
task.setWaiting(100)
self.processCaptcha(task)
else:
@@ -150,7 +150,7 @@ class CaptchaBrotherhood(Addon):
def captchaInvalid(self, task):
- if task.data['service'] == self.__name and "ticket" in task.data:
+ if task.data['service'] == self.__name__ and "ticket" in task.data:
res = self.get_api("complainCaptcha", task.data['ticket'])
diff --git a/pyload/plugin/hook/DeathByCaptcha.py b/pyload/plugin/hook/DeathByCaptcha.py
index 92bfa1e70..9460a0cee 100644
--- a/pyload/plugin/hook/DeathByCaptcha.py
+++ b/pyload/plugin/hook/DeathByCaptcha.py
@@ -49,17 +49,17 @@ class DeathByCaptchaException(Exception):
class DeathByCaptcha(Addon):
- __name = "DeathByCaptcha"
- __type = "hook"
- __version = "0.04"
+ __name__ = "DeathByCaptcha"
+ __type__ = "hook"
+ __version__ = "0.04"
- __config = [("username", "str", "Username", ""),
+ __config__ = [("username", "str", "Username", ""),
("passkey", "password", "Password", ""),
("force", "bool", "Force DBC even if client is connected", False)]
- __description = """Send captchas to DeathByCaptcha.com"""
- __license = "GPLv3"
- __authors = [("RaNaN", "RaNaN@pyload.org"),
+ __description__ = """Send captchas to DeathByCaptcha.com"""
+ __license__ = "GPLv3"
+ __authors__ = [("RaNaN", "RaNaN@pyload.org"),
("zoidberg", "zoidberg@mujmail.cz")]
@@ -183,13 +183,13 @@ class DeathByCaptcha(Addon):
if balance > rate:
task.handler.append(self)
- task.data['service'] = self.__name
+ task.data['service'] = self.__name__
task.setWaiting(180)
self.processCaptcha(task)
def captchaInvalid(self, task):
- if task.data['service'] == self.__name and "ticket" in task.data:
+ if task.data['service'] == self.__name__ and "ticket" in task.data:
try:
res = self.call_api("captcha/%d/report" % task.data['ticket'], True)
diff --git a/pyload/plugin/hook/DebridItaliaCom.py b/pyload/plugin/hook/DebridItaliaCom.py
index bce99abb2..ba3bff71e 100644
--- a/pyload/plugin/hook/DebridItaliaCom.py
+++ b/pyload/plugin/hook/DebridItaliaCom.py
@@ -7,18 +7,18 @@ from pyload.plugin.internal.MultiHoster import MultiHoster
class DebridItaliaCom(MultiHoster):
- __name = "DebridItaliaCom"
- __type = "hook"
- __version = "0.08"
+ __name__ = "DebridItaliaCom"
+ __type__ = "hook"
+ __version__ = "0.08"
- __config = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported)", "all"),
+ __config__ = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported)", "all"),
("hosterList", "str", "Hoster list (comma separated)", ""),
("unloadFailing", "bool", "Revert to standard download if download fails", False),
("interval", "int", "Reload interval in hours (0 to disable)", 24)]
- __description = """Debriditalia.com hook plugin"""
- __license = "GPLv3"
- __authors = [("stickell", "l.stickell@yahoo.it"),
+ __description__ = """Debriditalia.com hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("stickell", "l.stickell@yahoo.it"),
("Walter Purcaro", "vuolter@gmail.com")]
diff --git a/pyload/plugin/hook/EasybytezCom.py b/pyload/plugin/hook/EasybytezCom.py
index b401809fb..e5e012976 100644
--- a/pyload/plugin/hook/EasybytezCom.py
+++ b/pyload/plugin/hook/EasybytezCom.py
@@ -6,20 +6,20 @@ from pyload.plugin.internal.MultiHoster import MultiHoster
class EasybytezCom(MultiHoster):
- __name = "EasybytezCom"
- __type = "hook"
- __version = "0.03"
+ __name__ = "EasybytezCom"
+ __type__ = "hook"
+ __version__ = "0.03"
- __config = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported)", "all"),
+ __config__ = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported)", "all"),
("hosterList", "str", "Hoster list (comma separated)", "")]
- __description = """EasyBytez.com hook plugin"""
- __license = "GPLv3"
- __authors = [("zoidberg", "zoidberg@mujmail.cz")]
+ __description__ = """EasyBytez.com hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("zoidberg", "zoidberg@mujmail.cz")]
def getHoster(self):
- self.account = self.core.accountManager.getAccountPlugin(self.__name)
+ self.account = self.core.accountManager.getAccountPlugin(self.__name__)
user = self.account.selectAccount()[0]
try:
diff --git a/pyload/plugin/hook/ExpertDecoders.py b/pyload/plugin/hook/ExpertDecoders.py
index ed8edbf69..37bb4fbbe 100644
--- a/pyload/plugin/hook/ExpertDecoders.py
+++ b/pyload/plugin/hook/ExpertDecoders.py
@@ -12,16 +12,16 @@ from pyload.plugin.Addon import Addon
class ExpertDecoders(Addon):
- __name = "ExpertDecoders"
- __type = "hook"
- __version = "0.02"
+ __name__ = "ExpertDecoders"
+ __type__ = "hook"
+ __version__ = "0.02"
- __config = [("force", "bool", "Force CT even if client is connected", False),
+ __config__ = [("force", "bool", "Force CT even if client is connected", False),
("passkey", "password", "Access key", "")]
- __description = """Send captchas to expertdecoders.com"""
- __license = "GPLv3"
- __authors = [("RaNaN", "RaNaN@pyload.org"),
+ __description__ = """Send captchas to expertdecoders.com"""
+ __license__ = "GPLv3"
+ __authors__ = [("RaNaN", "RaNaN@pyload.org"),
("zoidberg", "zoidberg@mujmail.cz")]
diff --git a/pyload/plugin/hook/FastixRu.py b/pyload/plugin/hook/FastixRu.py
index 4bfec052e..4b840e9b4 100644
--- a/pyload/plugin/hook/FastixRu.py
+++ b/pyload/plugin/hook/FastixRu.py
@@ -6,17 +6,17 @@ from pyload.plugin.internal.MultiHoster import MultiHoster
class FastixRu(MultiHoster):
- __name = "FastixRu"
- __type = "hook"
- __version = "0.02"
+ __name__ = "FastixRu"
+ __type__ = "hook"
+ __version__ = "0.02"
- __config = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported)", "all"),
+ __config__ = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported)", "all"),
("unloadFailing", "bool", "Revert to standard download if download fails", False),
("interval", "int", "Reload interval in hours (0 to disable)", 24)]
- __description = """Fastix.ru hook plugin"""
- __license = "GPLv3"
- __authors = [("Massimo Rosamilia", "max@spiritix.eu")]
+ __description__ = """Fastix.ru hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("Massimo Rosamilia", "max@spiritix.eu")]
def getHoster(self):
diff --git a/pyload/plugin/hook/FreeWayMe.py b/pyload/plugin/hook/FreeWayMe.py
index 910c9d640..f901b4ec0 100644
--- a/pyload/plugin/hook/FreeWayMe.py
+++ b/pyload/plugin/hook/FreeWayMe.py
@@ -5,18 +5,18 @@ from pyload.plugin.internal.MultiHoster import MultiHoster
class FreeWayMe(MultiHoster):
- __name = "FreeWayMe"
- __type = "hook"
- __version = "0.11"
+ __name__ = "FreeWayMe"
+ __type__ = "hook"
+ __version__ = "0.11"
- __config = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported):", "all"),
+ __config__ = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported):", "all"),
("hosterList", "str", "Hoster list (comma separated)", ""),
("unloadFailing", "bool", "Revert to stanard download if download fails", False),
("interval", "int", "Reload interval in hours (0 to disable)", 24)]
- __description = """FreeWay.me hook plugin"""
- __license = "GPLv3"
- __authors = [("Nicolas Giese", "james@free-way.me")]
+ __description__ = """FreeWay.me hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("Nicolas Giese", "james@free-way.me")]
def getHoster(self):
diff --git a/pyload/plugin/hook/ImageTyperz.py b/pyload/plugin/hook/ImageTyperz.py
index 4ad37eb89..6ac75b1a1 100644
--- a/pyload/plugin/hook/ImageTyperz.py
+++ b/pyload/plugin/hook/ImageTyperz.py
@@ -30,17 +30,17 @@ class ImageTyperzException(Exception):
class ImageTyperz(Addon):
- __name = "ImageTyperz"
- __type = "hook"
- __version = "0.05"
+ __name__ = "ImageTyperz"
+ __type__ = "hook"
+ __version__ = "0.05"
- __config = [("username", "str", "Username", ""),
+ __config__ = [("username", "str", "Username", ""),
("passkey", "password", "Password", ""),
("force", "bool", "Force IT even if client is connected", False)]
- __description = """Send captchas to ImageTyperz.com"""
- __license = "GPLv3"
- __authors = [("RaNaN", "RaNaN@pyload.org"),
+ __description__ = """Send captchas to ImageTyperz.com"""
+ __license__ = "GPLv3"
+ __authors__ = [("RaNaN", "RaNaN@pyload.org"),
("zoidberg", "zoidberg@mujmail.cz")]
@@ -118,15 +118,15 @@ class ImageTyperz(Addon):
if self.getCredits() > 0:
task.handler.append(self)
- task.data['service'] = self.__name
+ task.data['service'] = self.__name__
task.setWaiting(100)
self.processCaptcha(task)
else:
- self.logInfo(_("Your %s account has not enough credits") % self.__name)
+ self.logInfo(_("Your %s account has not enough credits") % self.__name__)
def captchaInvalid(self, task):
- if task.data['service'] == self.__name and "ticket" in task.data:
+ if task.data['service'] == self.__name__ and "ticket" in task.data:
res = getURL(self.RESPOND_URL,
post={'action': "SETBADIMAGE",
'username': self.getConfig("username"),
diff --git a/pyload/plugin/hook/LinkdecrypterCom.py b/pyload/plugin/hook/LinkdecrypterCom.py
index 6465d95e0..fff596386 100644
--- a/pyload/plugin/hook/LinkdecrypterCom.py
+++ b/pyload/plugin/hook/LinkdecrypterCom.py
@@ -8,13 +8,13 @@ from pyload.utils import remove_chars
class LinkdecrypterCom(Addon):
- __name = "LinkdecrypterCom"
- __type = "hook"
- __version = "0.21"
+ __name__ = "LinkdecrypterCom"
+ __type__ = "hook"
+ __version__ = "0.21"
- __description = """Linkdecrypter.com hook plugin"""
- __license = "GPLv3"
- __authors = [("zoidberg", "zoidberg@mujmail.cz")]
+ __description__ = """Linkdecrypter.com hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("zoidberg", "zoidberg@mujmail.cz")]
def activate(self):
@@ -53,7 +53,7 @@ class LinkdecrypterCom(Addon):
regexp = r'https?://([^.]+\.)*?(%s)/.*' % '|'.join(online)
- dict = self.core.pluginManager.crypterPlugins[self.__name]
+ dict = self.core.pluginManager.crypterPlugins[self.__name__]
dict['pattern'] = regexp
dict['re'] = re.compile(regexp)
diff --git a/pyload/plugin/hook/LinksnappyCom.py b/pyload/plugin/hook/LinksnappyCom.py
index 487927724..f3c9ccaad 100644
--- a/pyload/plugin/hook/LinksnappyCom.py
+++ b/pyload/plugin/hook/LinksnappyCom.py
@@ -6,18 +6,18 @@ from pyload.plugin.internal.MultiHoster import MultiHoster
class LinksnappyCom(MultiHoster):
- __name = "LinksnappyCom"
- __type = "hook"
- __version = "0.01"
+ __name__ = "LinksnappyCom"
+ __type__ = "hook"
+ __version__ = "0.01"
- __config = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported)", "all"),
+ __config__ = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported)", "all"),
("hosterList", "str", "Hoster list (comma separated)", ""),
("unloadFailing", "bool", "Revert to standard download if download fails", False),
("interval", "int", "Reload interval in hours (0 to disable)", 24)]
- __description = """Linksnappy.com hook plugin"""
- __license = "GPLv3"
- __authors = [("stickell", "l.stickell@yahoo.it")]
+ __description__ = """Linksnappy.com hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("stickell", "l.stickell@yahoo.it")]
def getHoster(self):
diff --git a/pyload/plugin/hook/MegaDebridEu.py b/pyload/plugin/hook/MegaDebridEu.py
index 88a3bbe49..a125481c4 100644
--- a/pyload/plugin/hook/MegaDebridEu.py
+++ b/pyload/plugin/hook/MegaDebridEu.py
@@ -6,15 +6,15 @@ from pyload.plugin.internal.MultiHoster import MultiHoster
class MegaDebridEu(MultiHoster):
- __name = "MegaDebridEu"
- __type = "hook"
- __version = "0.02"
+ __name__ = "MegaDebridEu"
+ __type__ = "hook"
+ __version__ = "0.02"
- __config = [("unloadFailing", "bool", "Revert to standard download if download fails", False)]
+ __config__ = [("unloadFailing", "bool", "Revert to standard download if download fails", False)]
- __description = """mega-debrid.eu hook plugin"""
- __license = "GPLv3"
- __authors = [("D.Ducatel", "dducatel@je-geek.fr")]
+ __description__ = """mega-debrid.eu hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("D.Ducatel", "dducatel@je-geek.fr")]
def getHoster(self):
diff --git a/pyload/plugin/hook/MultishareCz.py b/pyload/plugin/hook/MultishareCz.py
index 58f721df2..791f65f6d 100644
--- a/pyload/plugin/hook/MultishareCz.py
+++ b/pyload/plugin/hook/MultishareCz.py
@@ -7,16 +7,16 @@ from pyload.plugin.internal.MultiHoster import MultiHoster
class MultishareCz(MultiHoster):
- __name = "MultishareCz"
- __type = "hook"
- __version = "0.04"
+ __name__ = "MultishareCz"
+ __type__ = "hook"
+ __version__ = "0.04"
- __config = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported)", "all"),
+ __config__ = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported)", "all"),
("hosterList", "str", "Hoster list (comma separated)", "uloz.to")]
- __description = """MultiShare.cz hook plugin"""
- __license = "GPLv3"
- __authors = [("zoidberg", "zoidberg@mujmail.cz")]
+ __description__ = """MultiShare.cz hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("zoidberg", "zoidberg@mujmail.cz")]
HOSTER_PATTERN = r'<img class="logo-shareserveru"[^>]*?alt="([^"]+)"></td>\s*<td class="stav">[^>]*?alt="OK"'
diff --git a/pyload/plugin/hook/MyfastfileCom.py b/pyload/plugin/hook/MyfastfileCom.py
index c9b3b2638..9e3709556 100644
--- a/pyload/plugin/hook/MyfastfileCom.py
+++ b/pyload/plugin/hook/MyfastfileCom.py
@@ -6,19 +6,19 @@ from pyload.utils import json_loads
class MyfastfileCom(MultiHoster):
- __name = "MyfastfileCom"
- __type = "hook"
- __version = "0.02"
+ __name__ = "MyfastfileCom"
+ __type__ = "hook"
+ __version__ = "0.02"
- __config = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported)", "all"),
+ __config__ = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported)", "all"),
("hosterList", "str", "Hoster list (comma separated)", ""),
("unloadFailing", "bool", "Revert to standard download if download fails", False),
("interval", "int", "Reload interval in hours (0 to disable)", 24)]
- __description = """Myfastfile.com hook plugin"""
- __license = "GPLv3"
- __authors = [("stickell", "l.stickell@yahoo.it")]
+ __description__ = """Myfastfile.com hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("stickell", "l.stickell@yahoo.it")]
diff --git a/pyload/plugin/hook/OverLoadMe.py b/pyload/plugin/hook/OverLoadMe.py
index 51d0b1dc1..93052c014 100644
--- a/pyload/plugin/hook/OverLoadMe.py
+++ b/pyload/plugin/hook/OverLoadMe.py
@@ -5,19 +5,19 @@ from pyload.plugin.internal.MultiHoster import MultiHoster
class OverLoadMe(MultiHoster):
- __name = "OverLoadMe"
- __type = "hook"
- __version = "0.01"
+ __name__ = "OverLoadMe"
+ __type__ = "hook"
+ __version__ = "0.01"
- __config = [("https", "bool", "Enable HTTPS", True),
+ __config__ = [("https", "bool", "Enable HTTPS", True),
("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported):", "all"),
("hosterList", "str", "Hoster list (comma separated)", ""),
("unloadFailing", "bool", "Revert to standard download if download fails", False),
("interval", "int", "Reload interval in hours (0 to disable)", 12)]
- __description = """Over-Load.me hook plugin"""
- __license = "GPLv3"
- __authors = [("marley", "marley@over-load.me")]
+ __description__ = """Over-Load.me hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("marley", "marley@over-load.me")]
def getHoster(self):
diff --git a/pyload/plugin/hook/PremiumTo.py b/pyload/plugin/hook/PremiumTo.py
index 25fb70e8d..08c3dc6bd 100644
--- a/pyload/plugin/hook/PremiumTo.py
+++ b/pyload/plugin/hook/PremiumTo.py
@@ -5,16 +5,16 @@ from pyload.plugin.internal.MultiHoster import MultiHoster
class PremiumTo(MultiHoster):
- __name = "PremiumTo"
- __type = "hook"
- __version = "0.04"
+ __name__ = "PremiumTo"
+ __type__ = "hook"
+ __version__ = "0.04"
- __config = [("hosterListMode", "all;listed;unlisted", "Use for downloads from supported hosters:", "all"),
+ __config__ = [("hosterListMode", "all;listed;unlisted", "Use for downloads from supported hosters:", "all"),
("hosterList", "str", "Hoster list (comma separated)", "")]
- __description = """Premium.to hook plugin"""
- __license = "GPLv3"
- __authors = [("RaNaN", "RaNaN@pyload.org"),
+ __description__ = """Premium.to hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("RaNaN", "RaNaN@pyload.org"),
("zoidberg", "zoidberg@mujmail.cz"),
("stickell", "l.stickell@yahoo.it")]
diff --git a/pyload/plugin/hook/PremiumizeMe.py b/pyload/plugin/hook/PremiumizeMe.py
index 981c671b9..5199adc2f 100644
--- a/pyload/plugin/hook/PremiumizeMe.py
+++ b/pyload/plugin/hook/PremiumizeMe.py
@@ -6,18 +6,18 @@ from pyload.plugin.internal.MultiHoster import MultiHoster
class PremiumizeMe(MultiHoster):
- __name = "PremiumizeMe"
- __type = "hook"
- __version = "0.12"
+ __name__ = "PremiumizeMe"
+ __type__ = "hook"
+ __version__ = "0.12"
- __config = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported):", "all"),
+ __config__ = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported):", "all"),
("hosterList", "str", "Hoster list (comma separated)", ""),
("unloadFailing", "bool", "Revert to stanard download if download fails", False),
("interval", "int", "Reload interval in hours (0 to disable)", 24)]
- __description = """Premiumize.me hook plugin"""
- __license = "GPLv3"
- __authors = [("Florian Franzen", "FlorianFranzen@gmail.com")]
+ __description__ = """Premiumize.me hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("Florian Franzen", "FlorianFranzen@gmail.com")]
def getHoster(self):
diff --git a/pyload/plugin/hook/RPNetBiz.py b/pyload/plugin/hook/RPNetBiz.py
index b976aa262..f58387dda 100644
--- a/pyload/plugin/hook/RPNetBiz.py
+++ b/pyload/plugin/hook/RPNetBiz.py
@@ -6,18 +6,18 @@ from pyload.plugin.internal.MultiHoster import MultiHoster
class RPNetBiz(MultiHoster):
- __name = "RPNetBiz"
- __type = "hook"
- __version = "0.10"
+ __name__ = "RPNetBiz"
+ __type__ = "hook"
+ __version__ = "0.10"
- __config = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported):", "all"),
+ __config__ = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported):", "all"),
("hosterList", "str", "Hoster list (comma separated)", ""),
("unloadFailing", "bool", "Revert to stanard download if download fails", False),
("interval", "int", "Reload interval in hours (0 to disable)", 24)]
- __description = """RPNet.biz hook plugin"""
- __license = "GPLv3"
- __authors = [("Dman", "dmanugm@gmail.com")]
+ __description__ = """RPNet.biz hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("Dman", "dmanugm@gmail.com")]
def getHoster(self):
diff --git a/pyload/plugin/hook/RealdebridCom.py b/pyload/plugin/hook/RealdebridCom.py
index 2584132b8..a7e3a08cd 100644
--- a/pyload/plugin/hook/RealdebridCom.py
+++ b/pyload/plugin/hook/RealdebridCom.py
@@ -5,19 +5,19 @@ from pyload.plugin.internal.MultiHoster import MultiHoster
class RealdebridCom(MultiHoster):
- __name = "RealdebridCom"
- __type = "hook"
- __version = "0.43"
+ __name__ = "RealdebridCom"
+ __type__ = "hook"
+ __version__ = "0.43"
- __config = [("https", "bool", "Enable HTTPS", False),
+ __config__ = [("https", "bool", "Enable HTTPS", False),
("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported):", "all"),
("hosterList", "str", "Hoster list (comma separated)", ""),
("unloadFailing", "bool", "Revert to stanard download if download fails", False),
("interval", "int", "Reload interval in hours (0 to disable)", 24)]
- __description = """Real-Debrid.com hook plugin"""
- __license = "GPLv3"
- __authors = [("Devirex Hazzard", "naibaf_11@yahoo.de")]
+ __description__ = """Real-Debrid.com hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("Devirex Hazzard", "naibaf_11@yahoo.de")]
def getHoster(self):
diff --git a/pyload/plugin/hook/RehostTo.py b/pyload/plugin/hook/RehostTo.py
index fd51bad12..cf993a79b 100644
--- a/pyload/plugin/hook/RehostTo.py
+++ b/pyload/plugin/hook/RehostTo.py
@@ -5,18 +5,18 @@ from pyload.plugin.internal.MultiHoster import MultiHoster
class RehostTo(MultiHoster):
- __name = "RehostTo"
- __type = "hook"
- __version = "0.43"
+ __name__ = "RehostTo"
+ __type__ = "hook"
+ __version__ = "0.43"
- __config = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported)", "all"),
+ __config__ = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported)", "all"),
("hosterList", "str", "Hoster list (comma separated)", ""),
("unloadFailing", "bool", "Revert to stanard download if download fails", False),
("interval", "int", "Reload interval in hours (0 to disable)", 24)]
- __description = """Rehost.to hook plugin"""
- __license = "GPLv3"
- __authors = [("RaNaN", "RaNaN@pyload.org")]
+ __description__ = """Rehost.to hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("RaNaN", "RaNaN@pyload.org")]
def getHoster(self):
diff --git a/pyload/plugin/hook/SimplyPremiumCom.py b/pyload/plugin/hook/SimplyPremiumCom.py
index e71a7a1c8..1e280eca2 100644
--- a/pyload/plugin/hook/SimplyPremiumCom.py
+++ b/pyload/plugin/hook/SimplyPremiumCom.py
@@ -6,18 +6,18 @@ from pyload.plugin.internal.MultiHoster import MultiHoster
class SimplyPremiumCom(MultiHoster):
- __name = "SimplyPremiumCom"
- __type = "hook"
- __version = "0.02"
+ __name__ = "SimplyPremiumCom"
+ __type__ = "hook"
+ __version__ = "0.02"
- __config = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported)", "all"),
+ __config__ = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported)", "all"),
("hosterList", "str", "Hoster list (comma separated)", ""),
("unloadFailing", "bool", "Revert to standard download if download fails", "False"),
("interval", "int", "Reload interval in hours (0 to disable)", "24")]
- __description = """Simply-Premium.com hook plugin"""
- __license = "GPLv3"
- __authors = [("EvolutionClip", "evolutionclip@live.de")]
+ __description__ = """Simply-Premium.com hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("EvolutionClip", "evolutionclip@live.de")]
def getHoster(self):
diff --git a/pyload/plugin/hook/SimplydebridCom.py b/pyload/plugin/hook/SimplydebridCom.py
index 6283032e5..650de5545 100644
--- a/pyload/plugin/hook/SimplydebridCom.py
+++ b/pyload/plugin/hook/SimplydebridCom.py
@@ -5,16 +5,16 @@ from pyload.plugin.internal.MultiHoster import MultiHoster
class SimplydebridCom(MultiHoster):
- __name = "SimplydebridCom"
- __type = "hook"
- __version = "0.01"
+ __name__ = "SimplydebridCom"
+ __type__ = "hook"
+ __version__ = "0.01"
- __config = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported)", "all"),
+ __config__ = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported)", "all"),
("hosterList", "str", "Hoster list (comma separated)", "")]
- __description = """Simply-Debrid.com hook plugin"""
- __license = "GPLv3"
- __authors = [("Kagenoshin", "kagenoshin@gmx.ch")]
+ __description__ = """Simply-Debrid.com hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("Kagenoshin", "kagenoshin@gmx.ch")]
def getHoster(self):
diff --git a/pyload/plugin/hook/UnrestrictLi.py b/pyload/plugin/hook/UnrestrictLi.py
index a478545d6..8a3b2a040 100644
--- a/pyload/plugin/hook/UnrestrictLi.py
+++ b/pyload/plugin/hook/UnrestrictLi.py
@@ -6,19 +6,19 @@ from pyload.plugin.internal.MultiHoster import MultiHoster
class UnrestrictLi(MultiHoster):
- __name = "UnrestrictLi"
- __type = "hook"
- __version = "0.02"
+ __name__ = "UnrestrictLi"
+ __type__ = "hook"
+ __version__ = "0.02"
- __config = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported)", "all"),
+ __config__ = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported)", "all"),
("hosterList", "str", "Hoster list (comma separated)", ""),
("unloadFailing", "bool", "Revert to standard download if download fails", False),
("interval", "int", "Reload interval in hours (0 to disable)", 24),
("history", "bool", "Delete History", False)]
- __description = """Unrestrict.li hook plugin"""
- __license = "GPLv3"
- __authors = [("stickell", "l.stickell@yahoo.it")]
+ __description__ = """Unrestrict.li hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("stickell", "l.stickell@yahoo.it")]
def getHoster(self):
diff --git a/pyload/plugin/hook/ZeveraCom.py b/pyload/plugin/hook/ZeveraCom.py
index af93f1a7f..e41796a1a 100644
--- a/pyload/plugin/hook/ZeveraCom.py
+++ b/pyload/plugin/hook/ZeveraCom.py
@@ -5,16 +5,16 @@ from pyload.plugin.internal.MultiHoster import MultiHoster
class ZeveraCom(MultiHoster):
- __name = "ZeveraCom"
- __type = "hook"
- __version = "0.02"
+ __name__ = "ZeveraCom"
+ __type__ = "hook"
+ __version__ = "0.02"
- __config = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported)", "all"),
+ __config__ = [("hosterListMode", "all;listed;unlisted", "Use for hosters (if supported)", "all"),
("hosterList", "str", "Hoster list (comma separated)", "")]
- __description = """Real-Debrid.com hook plugin"""
- __license = "GPLv3"
- __authors = [("zoidberg", "zoidberg@mujmail.cz")]
+ __description__ = """Real-Debrid.com hook plugin"""
+ __license__ = "GPLv3"
+ __authors__ = [("zoidberg", "zoidberg@mujmail.cz")]
def getHoster(self):
diff --git a/pyload/plugin/hook/XFileSharingPro.py b/pyload/plugin/hook/XFileSharingPro.py
index b478245dc..8fb04cf13 100644
--- a/pyload/plugin/hook/XFileSharingPro.py
+++ b/pyload/plugin/hook/XFileSharingPro.py
@@ -6,20 +6,20 @@ from pyload.plugin.Addon import Addon
class XFileSharingPro(Addon):
- __name = "XFileSharingPro"
- __type = "hook"
- __version = "0.26"
+ __name__ = "XFileSharingPro"
+ __type__ = "hook"
+ __version__ = "0.26"
- __config = [("activated" , "bool", "Activated" , True ),
+ __config__ = [("activated" , "bool", "Activated" , True ),
("use_hoster_list" , "bool", "Load listed hosters only" , True ),
("use_crypter_list", "bool", "Load listed crypters only" , False),
("use_builtin_list", "bool", "Load built-in plugin list" , True ),
("hoster_list" , "str" , "Hoster list (comma separated)" , "" ),
("crypter_list" , "str" , "Crypter list (comma separated)", "" )]
- __description = """Load XFileSharingPro based hosters and crypter which don't need a own plugin to run"""
- __license = "GPLv3"
- __authors = [("Walter Purcaro", "vuolter@gmail.com")]
+ __description__ = """Load XFileSharingPro based hosters and crypter which don't need a own plugin to run"""
+ __license__ = "GPLv3"
+ __authors__ = [("Walter Purcaro", "vuolter@gmail.com")]
# event_list = ["pluginConfigChanged"]
@@ -40,7 +40,7 @@ class XFileSharingPro(Addon):
CRYPTER_LIST = []
# def pluginConfigChanged(self.__name, plugin, name, value):
# self.loadPattern()
@@ -40,7 +40,7 @@ class XFileSharingPro(Addon):
CRYPTER_LIST = []
- # def pluginConfigChanged(self.__name, plugin, name, value):
+ # def pluginConfigChanged(self.__name__, plugin, name, value):
# self.loadPattern()